==> slo-converter-0.1.0.crate: slo-converter-0.1.0/terraform/slis.tf <==
resource "datadog_monitor" "test_slo_converter_sli_1" {
  name    = "test slo converter sli 1"
  type    = "metric alert"
  message = <<EOT
This is the message text for this monitor.

This is an example of line two with a blank line between.
@slack-temp-slo-monitoring
EOT
  query   = "percentile(last_5m):p95:trace.http.request{(resource_name:post_/api/v1/deployments OR resource_name:get_/api/v1/deployments OR resource_name:post_/api/v1/deployments/) AND service:devops-portal} > 1"
  tags    = ["tag1", "tag2"]
}
resource "datadog_monitor" "test_slo_converter_sli_1" {
  name    = "test slo converter sli 1"
  type    = "metric alert"
  message = <<EOT
This is the message text for this monitor.

This is an example of line two with a blank line between.
@slack-temp-slo-monitoring
EOT
  query   = "percentile(last_5m):p95:trace.http.request{(resource_name:post_/api/v1/deployments OR resource_name:get_/api/v1/deployments OR resource_name:post_/api/v1/deployments/) AND service:devops-portal} > 1"
  tags    = ["tag1", "tag2"]
}
resource "datadog_monitor" "test_slo_converter_sli_2" {
  name    = "test slo converter sli 2"
  type    = "metric alert"
  message = "Here's another message for a second monitor. @slack-temp-slo-monitoring"
  query   = "sum(last_5m):sum:trace.http.request.errors{(resource_name:post_/api/v1/deployments OR resource_name:get_/api/v1/deployments OR resource_name:post_/api/v1/deployments/) AND service:devops-portal}.as_count() / sum:trace.http.request.hits{(resource_name:post_/api/v1/deployments OR resource_name:get_/api/v1/deployments OR resource_name:post_/api/v1/deployments/) AND service:devops-portal}.as_count() > 1"
  tags    = ["tag1", "tag2"]
}
resource "datadog_monitor" "test_slo_converter_sli_2" {
  name    = "test slo converter sli 2"
  type    = "metric alert"
  message = "Here's another message for a second monitor. @slack-temp-slo-monitoring"
  query   = "sum(last_5m):sum:trace.http.request.errors{(resource_name:post_/api/v1/deployments OR resource_name:get_/api/v1/deployments OR resource_name:post_/api/v1/deployments/) AND service:devops-portal}.as_count() / sum:trace.http.request.hits{(resource_name:post_/api/v1/deployments OR resource_name:get_/api/v1/deployments OR resource_name:post_/api/v1/deployments/) AND service:devops-portal}.as_count() > 1"
  tags    = ["tag1", "tag2"]
}
resource "datadog_service_level_objective" "test-slo-converter-slo-1" {
  name        = "test slo converter slo 1"
  type        = "monitor"
  monitor_ids = [datadog_monitor.test_slo_converter_sli_1.id, datadog_monitor.test_slo_converter_sli_2.id]
}
resource "datadog_service_level_objective" "test-slo-converter-slo-1" {
  name        = "test slo converter slo 1"
  type        = "monitor"
  monitor_ids = [datadog_monitor.test_slo_converter_sli_1.id, datadog_monitor.test_slo_converter_sli_2.id]
}

==> slo-converter-0.1.1.crate: slo-converter-0.1.1/terraform/slis.tf <==
resource "datadog_monitor" "test_slo_converter_sli_1" {
  name    = "test slo converter sli 1"
  type    = "metric alert"
  message = <<EOT
This is the message text for this monitor.

This is an example of line two with a blank line between.
@slack-temp-slo-monitoring
EOT
  query   = "percentile(last_5m):p95:trace.http.request{(resource_name:post_/api/v1/deployments OR resource_name:get_/api/v1/deployments OR resource_name:post_/api/v1/deployments/) AND service:devops-portal} > 1"
  monitor_thresholds {
    warning  = "0.8"
    critical = "1"
  }
  tags = ["tag1", "tag2"]
}
resource "datadog_monitor" "test_slo_converter_sli_2" {
  name    = "test slo converter sli 2"
  type    = "metric alert"
  message = "Here's another message for a second monitor. @slack-temp-slo-monitoring"
  query   = "sum(last_5m):sum:trace.http.request.errors{(resource_name:post_/api/v1/deployments OR resource_name:get_/api/v1/deployments OR resource_name:post_/api/v1/deployments/) AND service:devops-portal}.as_count() / sum:trace.http.request.hits{(resource_name:post_/api/v1/deployments OR resource_name:get_/api/v1/deployments OR resource_name:post_/api/v1/deployments/) AND service:devops-portal}.as_count() > 1"
  monitor_thresholds {
    warning  = "0.8"
    critical = "1"
  }
  tags = ["tag1", "tag2"]
}
resource "datadog_monitor" "test_slo_converter_sli_3" {
  name    = "test slo converter sli 3"
  type    = "metric alert"
  message = <<EOT
This is the message text for this monitor.

This is an example of line two with a blank line between.
@slack-temp-slo-monitoring
EOT
  query   = "percentile(last_5m):p95:trace.http.request{(resource_name:post_/api/v1/deployments OR resource_name:get_/api/v1/deployments OR resource_name:post_/api/v1/deployments/) AND service:devops-portal} > 1"
  monitor_thresholds {
    warning  = "0.8"
    critical = "1"
  }
  tags = ["tag1", "tag2"]
}
resource "datadog_monitor" "test_slo_converter_sli_4" {
  name    = "test slo converter sli 4"
  type    = "metric alert"
  message = "Here's another message for a second monitor. @slack-temp-slo-monitoring"
  query   = "sum(last_5m):sum:trace.http.request.errors{(resource_name:post_/api/v1/deployments OR resource_name:get_/api/v1/deployments OR resource_name:post_/api/v1/deployments/) AND service:devops-portal}.as_count() / sum:trace.http.request.hits{(resource_name:post_/api/v1/deployments OR resource_name:get_/api/v1/deployments OR resource_name:post_/api/v1/deployments/) AND service:devops-portal}.as_count() > 1"
  monitor_thresholds {
    warning  = "0.8"
    critical = "1"
  }
  tags = ["tag1", "tag2"]
}
resource "datadog_service_level_objective" "test_slo_converter_slo_1" {
  name        = "test slo converter slo 1"
  type        = "monitor"
  monitor_ids = [datadog_monitor.test_slo_converter_sli_1.id, datadog_monitor.test_slo_converter_sli_2.id]
  thresholds {
    timeframe = "7d"
    target    = "99.9"
  }
  thresholds {
    timeframe = "30d"
    target    = "99.9"
  }
  thresholds {
    timeframe = "90d"
    target    = "99.9"
  }
  tags = ["tag1", "tag2", "tag1", "tag2"]
}
resource "datadog_service_level_objective" "test_slo_converter_slo_2" {
  name        = "test slo converter slo 2"
  type        = "monitor"
  monitor_ids = [datadog_monitor.test_slo_converter_sli_3.id, datadog_monitor.test_slo_converter_sli_4.id]
  thresholds {
    timeframe = "7d"
    target    = "99.9"
  }
  thresholds {
    timeframe = "30d"
    target    = "99.9"
  }
  thresholds {
    timeframe = "90d"
    target    = "99.9"
  }
  tags = ["tag1", "tag2", "tag1", "tag2"]
}
